[![pipeline status](https://gitlab.com/computationalmaterials/clease-gui/badges/master/pipeline.svg)](https://gitlab.com/computationalmaterials/clease-gui/-/commits/master) 
[![coverage report](https://gitlab.com/computationalmaterials/clease-gui/badges/master/coverage.svg)](https://gitlab.com/computationalmaterials/clease-gui/-/commits/master)
[![Documentation Status](https://readthedocs.org/projects/clease-gui/badge/?version=latest)](https://clease-gui.readthedocs.io/en/latest/?badge=latest)

## CLEASE GUI
This is a GUI based on Jupyter notebooks for [CLEASE](https://gitlab.com/computationalmaterials/clease).
For more information, head on over to the [documentation](https://clease-gui.readthedocs.io).

# Running the GUI
The GUI is based on Jupyter notebooks. To launch a new notebook, launch
```sh
jupyter notebook
```
Create a new notebook that you want to work in, and a new cell, add the following lines:
```python
from clease_gui import display_ui
display_ui()
```


A line `%matplotlib notebook` can be added at the start of the cell for nicer plots. However, this may come at a significant performance cost, so do your own testing.


## Plot font sizes

All plots generated in this package are generated by the ``matplotlib`` package. However, the default font size in ``matplotlib`` can be rather small,
so it can be adjusted globally, e.g. by running the following in a cell:
```python
import matplotlib
matplotlib.rcParams.update({'font.size': 16})
```
This will also affect the font sizes on the figures generated in the GUI.
